@@ -5,7 +5,10 @@ from time import time
 
 import numpy as np
 import matplotlib.pyplot as plt
-from skimage.metrics import normalized_root_mse as compare_nrmse # pylint: disable=E0611,E0401
+try:
+    from skimage.metrics import normalized_root_mse as compare_nrmse  # pylint: disable=E0611,E0401
+except ImportError:
+    from skimage.measure import compare_nrmse
 
 from pygrappa import grog, radialgrappaop
 
@@ -64,7 +67,6 @@ if __name__ == '__main__':
     res_prime = grog(kx, ky, k, N, N, Gx, Gy, use_primefac=True)
     print('Gridded in %g seconds (primefac)' % (time() - t0))
 
-
     res = np.fft.fftshift(np.fft.ifft2(np.fft.ifftshift(
         res, axes=(0, 1)), axes=(0, 1)), axes=(0, 1))
     res = np.sqrt(np.sum(np.abs(res)**2, axis=-1))
